<?php

namespace Slider\Com.ryo.test\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Slider\Com.ryo.test\Http\Requests\PisturesRequest;
use Slider\Com.ryo.test\Interfaces\PisturesRepositoryInterface;
use Slider\Com.ryo.test\Models\Pistures;

/**
 * Resource controller class for pistures.
 */
class PisturesResourceController extends BaseController
{

    /**
     * Initialize pistures resource controller.
     *
     * @param type PisturesRepositoryInterface $pistures
     *
     * @return null
     */
    public function __construct(PisturesRepositoryInterface $pistures)
    {
        parent::__construct();
        $this->repository = $pistures;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Slider\Com.ryo.test\Repositories\Criteria\PisturesResourceCriteria::class);
    }

    /**
     * Display a list of pistures.
     *
     * @return Response
     */
    public function index(PisturesRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Slider\Com.ryo.test\Repositories\Presenter\PisturesPresenter::class)
                ->$function();
        }

        $pistures = $this->repository->paginate();

        return $this->response->title(trans('com.ryo.test::pistures.names'))
            ->view('com.ryo.test::pistures.index', true)
            ->data(compact('pistures'))
            ->output();
    }

    /**
     * Display pistures.
     *
     * @param Request $request
     * @param Model   $pistures
     *
     * @return Response
     */
    public function show(PisturesRequest $request, Pistures $pistures)
    {

        if ($pistures->exists) {
            $view = 'com.ryo.test::pistures.show';
        } else {
            $view = 'com.ryo.test::pistures.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('com.ryo.test::pistures.name'))
            ->data(compact('pistures'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new pistures.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(PisturesRequest $request)
    {

        $pistures = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('com.ryo.test::pistures.name')) 
            ->view('com.ryo.test::pistures.create', true) 
            ->data(compact('pistures'))
            ->output();
    }

    /**
     * Create new pistures.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(PisturesRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $pistures                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('com.ryo.test::pistures.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('com.ryo.test/pistures/' . $pistures->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/com.ryo.test/pistures'))
                ->redirect();
        }

    }

    /**
     * Show pistures for editing.
     *
     * @param Request $request
     * @param Model   $pistures
     *
     * @return Response
     */
    public function edit(PisturesRequest $request, Pistures $pistures)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('com.ryo.test::pistures.name'))
            ->view('com.ryo.test::pistures.edit', true)
            ->data(compact('pistures'))
            ->output();
    }

    /**
     * Update the pistures.
     *
     * @param Request $request
     * @param Model   $pistures
     *
     * @return Response
     */
    public function update(PisturesRequest $request, Pistures $pistures)
    {
        try {
            $attributes = $request->all();

            $pistures->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('com.ryo.test::pistures.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('com.ryo.test/pistures/' . $pistures->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('com.ryo.test/pistures/' . $pistures->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the pistures.
     *
     * @param Model   $pistures
     *
     * @return Response
     */
    public function destroy(PisturesRequest $request, Pistures $pistures)
    {
        try {

            $pistures->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('com.ryo.test::pistures.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('com.ryo.test/pistures/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('com.ryo.test/pistures/' . $pistures->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple pistures.
     *
     * @param Model   $pistures
     *
     * @return Response
     */
    public function delete(PisturesRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('com.ryo.test::pistures.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('com.ryo.test/pistures'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/com.ryo.test/pistures'))
                ->redirect();
        }

    }

    /**
     * Restore deleted pistures.
     *
     * @param Model   $pistures
     *
     * @return Response
     */
    public function restore(PisturesRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('com.ryo.test::pistures.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/com.ryo.test/pistures'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/com.ryo.test/pistures/'))
                ->redirect();
        }

    }

}
