<?php

namespace Slider\Com.ryo.test\Policies;

use Litepie\User\Contracts\UserPolicy;
use Slider\Com.ryo.test\Models\Albums;

class AlbumsPolicy
{

    /**
     * Determine if the given user can view the albums.
     *
     * @param UserPolicy $user
     * @param Albums $albums
     *
     * @return bool
     */
    public function view(UserPolicy $user, Albums $albums)
    {
        if ($user->canDo('com.ryo.test.albums.view') && $user->isAdmin()) {
            return true;
        }

        return $albums->user_id == user_id() && $albums->user_type == user_type();
    }

    /**
     * Determine if the given user can create a albums.
     *
     * @param UserPolicy $user
     * @param Albums $albums
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('com.ryo.test.albums.create');
    }

    /**
     * Determine if the given user can update the given albums.
     *
     * @param UserPolicy $user
     * @param Albums $albums
     *
     * @return bool
     */
    public function update(UserPolicy $user, Albums $albums)
    {
        if ($user->canDo('com.ryo.test.albums.edit') && $user->isAdmin()) {
            return true;
        }

        return $albums->user_id == user_id() && $albums->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given albums.
     *
     * @param UserPolicy $user
     * @param Albums $albums
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Albums $albums)
    {
        return $albums->user_id == user_id() && $albums->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given albums.
     *
     * @param UserPolicy $user
     * @param Albums $albums
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Albums $albums)
    {
        if ($user->canDo('com.ryo.test.albums.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given albums.
     *
     * @param UserPolicy $user
     * @param Albums $albums
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Albums $albums)
    {
        if ($user->canDo('com.ryo.test.albums.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
