<?php

namespace Slider\Com.ryo.test\Providers;

use Illuminate\Support\ServiceProvider;

class Com.ryo.testServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'com.ryo.test');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'com.ryo.test');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('slider.com.ryo.test', function ($app) {
            return $this->app->make('Slider\Com.ryo.test\Com.ryo.test');
        });

        // Bind Banner to repository
        $this->app->bind(
            'Slider\Com.ryo.test\Interfaces\BannerRepositoryInterface',
            \Slider\Com.ryo.test\Repositories\Eloquent\BannerRepository::class
        );        // Bind Albums to repository
        $this->app->bind(
            'Slider\Com.ryo.test\Interfaces\AlbumsRepositoryInterface',
            \Slider\Com.ryo.test\Repositories\Eloquent\AlbumsRepository::class
        );        // Bind Pistures to repository
        $this->app->bind(
            'Slider\Com.ryo.test\Interfaces\PisturesRepositoryInterface',
            \Slider\Com.ryo.test\Repositories\Eloquent\PisturesRepository::class
        );

        $this->app->register(\Slider\Com.ryo.test\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Slider\Com.ryo.test\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['slider.com.ryo.test'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('slider/com.ryo.test.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/com.ryo.test')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/com.ryo.test')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
