<?php

namespace Slider\Com.ryo.test\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Slider\Com.ryo.test\Models\Com.ryo.test;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Slider\Com.ryo.test\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/com.ryo.test/banner/*')) {
            Route::bind('banner', function ($banner) {
                $bannerrepo = $this->app->make('Slider\Com.ryo.test\Interfaces\BannerRepositoryInterface');
                return $bannerrepo->findorNew($banner);
            });
        }
        if (Request::is('*/com.ryo.test/albums/*')) {
            Route::bind('albums', function ($albums) {
                $albumsrepo = $this->app->make('Slider\Com.ryo.test\Interfaces\AlbumsRepositoryInterface');
                return $albumsrepo->findorNew($albums);
            });
        }
        if (Request::is('*/com.ryo.test/pistures/*')) {
            Route::bind('pistures', function ($pistures) {
                $pisturesrepo = $this->app->make('Slider\Com.ryo.test\Interfaces\PisturesRepositoryInterface');
                return $pisturesrepo->findorNew($pistures);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {
        if (request()->segment(1) == 'api' || request()->segment(2) == 'api') {
            return;
        }
        
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
            'prefix'     => trans_setlocale(),
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

}
